pub struct ActivityMigrator;Trait Implementations
Sourceimpl MigratorTrait for ActivityMigrator
impl MigratorTrait for ActivityMigrator
Sourcefn migrations() -> Vec<Box<dyn MigrationTrait>>
fn migrations() -> Vec<Box<dyn MigrationTrait>>
Vector of migrations in time sequence
Sourcefn migration_table_name() -> DynIden
fn migration_table_name() -> DynIden
Name of the migration table, it is
seaql_migrations by defaultSourcefn get_migration_files() -> Vec<Migration>
fn get_migration_files() -> Vec<Migration>
Get list of migrations wrapped in
Migration structSourcefn get_migration_models<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Model>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
fn get_migration_models<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Model>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
Get list of applied migrations from database
Sourcefn get_migration_with_status<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
fn get_migration_with_status<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
Get list of migrations with status
Sourcefn get_pending_migrations<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
fn get_pending_migrations<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
Get list of pending migrations
Sourcefn get_applied_migrations<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
fn get_applied_migrations<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
Get list of applied migrations
Sourcefn get_migration_with_status_read_only<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
fn get_migration_with_status_read_only<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
Get list of migrations with status, without creating the migration table. Read more
Sourcefn get_pending_migrations_read_only<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
fn get_pending_migrations_read_only<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
Get list of pending migrations without creating the migration table. Read more
Sourcefn get_applied_migrations_read_only<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
fn get_applied_migrations_read_only<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<Vec<Migration>, DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
Get list of applied migrations without creating the migration table. Read more
Sourcefn install<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
fn install<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
Create migration table
seaql_migrations in the databaseSourcefn status<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
fn status<'life0, 'async_trait, C>(
db: &'life0 C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'life0: 'async_trait,
C: ConnectionTrait + 'async_trait,
Self: 'async_trait,
Check the status of all migrations
Sourcefn fresh<'c, 'async_trait, C>(
db: C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'c: 'async_trait,
C: IntoDatabaseExecutor<'c> + 'async_trait,
Self: 'async_trait,
fn fresh<'c, 'async_trait, C>(
db: C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'c: 'async_trait,
C: IntoDatabaseExecutor<'c> + 'async_trait,
Self: 'async_trait,
Drop all tables from the database, then reapply all migrations
Sourcefn refresh<'c, 'async_trait, C>(
db: C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'c: 'async_trait,
C: IntoDatabaseExecutor<'c> + 'async_trait,
Self: 'async_trait,
fn refresh<'c, 'async_trait, C>(
db: C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'c: 'async_trait,
C: IntoDatabaseExecutor<'c> + 'async_trait,
Self: 'async_trait,
Rollback all applied migrations, then reapply all migrations
Sourcefn reset<'c, 'async_trait, C>(
db: C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'c: 'async_trait,
C: IntoDatabaseExecutor<'c> + 'async_trait,
Self: 'async_trait,
fn reset<'c, 'async_trait, C>(
db: C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'c: 'async_trait,
C: IntoDatabaseExecutor<'c> + 'async_trait,
Self: 'async_trait,
Rollback all applied migrations
Sourcefn uninstall<'c, 'async_trait, C>(
db: C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'c: 'async_trait,
C: IntoDatabaseExecutor<'c> + 'async_trait,
Self: 'async_trait,
fn uninstall<'c, 'async_trait, C>(
db: C,
) -> Pin<Box<dyn Future<Output = Result<(), DbErr>> + Send + 'async_trait>>where
'c: 'async_trait,
C: IntoDatabaseExecutor<'c> + 'async_trait,
Self: 'async_trait,
Uninstall migration tracking table only (non-destructive)
This will drop the
seaql_migrations table but won’t rollback other schema changes.Auto Trait Implementations
impl Freeze for ActivityMigrator
impl RefUnwindSafe for ActivityMigrator
impl Send for ActivityMigrator
impl Sync for ActivityMigrator
impl Unpin for ActivityMigrator
impl UnsafeUnpin for ActivityMigrator
impl UnwindSafe for ActivityMigrator